OC.L10N.register(
    "news",
    {
    "News" : "Naujienos",
    "an article" : "straipsnis",
    "Someone" : "Kažkas",
    "%1$s shared \"%2$s\" with you" : "%1$s pradėjo bendrinti su jumis „%2$s“",
    "{user} shared \"{article}\" with you" : "{user} pasidalino su jumis „{article}“",
    "News feeds" : "Naujienų kanalai",
    "Unread articles" : "Neskaityti straipsniai",
    "News folders" : "Naujienų aplankai",
    "News articles" : "Naujienų straipsniai",
    "Shared with me" : "Bendrinta su manimi",
    "Untitled article" : "Straipsnis be pavadinimo",
    "Background job mode for feed updates" : "Fono užduočių režimas naujienų srauto atnaujinimams",
    "Feed update method is correctly configured." : "Srauto atnaujinimo metodas yra tinkamai sukonfigūruotas.",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Aptikta AJAX ar webcron veiksena! Jūsų kanalai nebus atnaujinti!",
    "An RSS/Atom feed reader" : "RSS/Atom kanalų skaitytuvė",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 RSS/Atom srautų skaityklė „Nextcloud“\n\n- 📲 Sinchronizuokite savo srautus su įvairiais mobiliaisiais ar staliniais [klientais](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatinis naujienų srautų atnaujinimas\n- 🆓 Nemokama ir atviro kodo pagal AGPLv3 licenciją, be reklamų ir mokamų funkcijų\n\n**Kad ši programa veiktų, šiuo metu reikalingas sistemos Cron**\n\nReikalavimus galite rasti [čia](https://nextcloud.github.io/news/install/#dependencies)\n\nPakeitimų sąrašą galite rasti [čia](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nPateikite [pranešimą apie klaidą](https://github.com/nextcloud/news/issues/new/choose)\n\nPateikite [prašymą dėl funkcijos](https://github.com/nextcloud/news/discussions/new)\n\nPraneškite apie [srauto problemą](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Atsisiųsti",
    "Close" : "Užverti",
    "Internal server error!" : "Vidinė serverio klaida!",
    "Unknown error!" : "Nežinoma klaida!",
    "Web address" : "Saityno adresas",
    "Please check your data/nextcloud.log file for additional information!" : "Daugiau informacijos rasite savo data/nextcloud.log faile!",
    "No folder" : "Be aplanko",
    "Folder name" : "Aplanko pavadinimas",
    "Username" : "Naudotojo vardas",
    "Password" : "Slaptažodis",
    "Feed exists already!" : "Kanalas jau yra!",
    "New folder" : "Naujas aplankas",
    "Folder exists already!" : "Aplankas jau yra!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth prisijungimo duomenys privalo būti laikomi nešifruotu pavidalu! Asmenys, turintys prieigą prie serverio ar duomenų bazės, galės matyti šiuos prisijungimo duomenis!",
    "Credentials" : "Prisijungimo duomenys ",
    "Auto discover Feed" : "Automatiškai atrasti kanalą",
    "Subscribe" : "Prenumeruoti",
    "Successfully updated news configuration" : "Naujienų konfigūracija sėkmingai atnaujinta",
    "Unable to update news config" : "Nepavyko atnaujinti naujienų konfigūracijos",
    "Logo purge has never been run." : "Logotipo valymas niekada nebuvo atliktas.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Paskutinis logotipo valymas buvo atliktas {relativeLastLogoPurge}. Kažkas negerai.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Paskutinė logotipo valymo užduotis buvo paleista {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Nėra jokių užduočių vykdymo duomenų. „Cron“ užduotis gali veikti netinkamai.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Paskutinė užduotis įvykdyta {relativeTime}. Kažkas negerai.",
    "Last job ran {relativeTime}." : "Paskutinis užduoties vykdymas buvo atliktas {relativeTime}.",
    "Maximum read count per feed" : "Didžiausias kanalo straipsnių kiekis",
    "Maximum redirects" : "Daugiausiai peradresavimų",
    "Feed fetcher timeout" : "Kanalų gavimui skirtas laikas",
    "Explore Service URL" : "Išžvalgymo paslaugos URL",
    "Update interval" : "Atnaujinimo intervalas",
    "Use system cron for updates" : "Atnaujinimams naudoti sistemos planuoklę (cron)",
    "Disable this if you use a custom updater." : "Išjunkite šią funkciją, jei naudojate pasirinktinį atnaujinimo įrankį.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Apibrėžia maksimalų straipsnių, kuriuos galima perskaityti viename kanale ir kurie nebus ištrinti valymo užduoties metu, skaičių; jei seni straipsniai vėl atsiranda po perskaitymo, padidinkite šią reikšmę; neigiamos reikšmės, pvz., -1, išjungs šią funkciją.",
    "Delete unread articles automatically" : "Automatiškai ištrinti neskaitytus straipsnius",
    "Enable this if you also want to delete unread articles." : "Įjunkite, jei tuo pačiu norite ištrinti neskaitytus straipsnius.",
    "How many redirects the feed fetcher should follow." : "Kiek kartų kanalų gaviklis turėtų sekti paskui peradresavimus.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimalus sekundžių skaičius, kurį reikia laukti, kol bus įkeltas RSS arba „Atom“ kanalas; jei tai užtruks ilgiau, atnaujinimas bus nutrauktas.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Jei šis URL adresas bus nurodytas, jis bus užklaustas, kad naujienų srautai būtų rodomi skyriuje „Naršyti naujienų srautus“. Norėdami naudoti įdiegtą „Naršyti“ paslaugą, palikite šį laukelį tuščią.",
    "Interval in seconds in which the feeds will be updated." : "Intervalas sekundėmis, per kurį bus atnaujinami informacijos srautai.",
    "Use next update time for feed updates" : "Naudoti kitą atnaujinimo laiką sklaidos kanalų atnaujinimams",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Įjunkite šią parinktį, jei norite, kad sklaidos kanalų atnaujinimams būtų naudojamas apskaičiuotas kito atnaujinimo laikas. Išjunkite, jei norite, kad sklaidos kanalai būtų atnaujinami tik pagal atnaujinimo intervalą.",
    "Article list" : "Straipsnių sąrašas",
    "Article details" : "Išsamiau apie straipsnį",
    "No article selected" : "Nepasirinktas joks straipsnis",
    "Please select an article from the list." : "Pasirinkite straipsnį iš sąrašo.",
    "Show all articles" : "Rodyti visus straipsnius",
    "Move feeds" : "Perkelti kanalus",
    "Move feed" : "Perkelti sklaidos kanalą",
    "Moving feeds…" : "Perkeliami kanalai…",
    "Unable to move feed. Please try again later or check your connection." : "Nepavyko perkelti sklaidos kanalo. Bandykite dar kartą vėliau arba patikrinkite ryšį.",
    "Some selected feeds could not be moved. Please try again later or check your connection." : "Kai kurių pasirinktų sklaidos kanalų nepavyko perkelti. Bandykite dar kartą vėliau arba patikrinkite ryšį.",
    "Please select the new folder" : "Pasirinkite naują aplanką",
    "Move" : "Perkelti",
    "User Name" : "Naudotojo vardas",
    "Share" : "Bendrinti",
    "Share with" : "Bendrinti su",
    "Share with {num} users" : "Bendrinkite su {num} vartotojais",
    "Rename Folder" : "Pervadinti aplanką",
    "Are you sure you want to delete?" : "Ar tikrai norite ištrinti?",
    "Unable to save starred open state" : "Nepavyko išsaugoti žvaigždute pažymėtos atidarymo būsenos",
    "Mark read" : "Žymėti kaip skaitytą",
    "All articles" : "Visi straipsniai",
    "Recently viewed" : "Neseniai žiūrėta",
    "Starred" : "Pažymėti žvaigždute",
    "Has feeds with errors!" : "Turi sklaidos srautus su klaidomis!",
    "Explore" : "Išvalgyti",
    "Feed settings" : "Sklaidos kanalo nustatymai",
    "News settings" : "Naujienų nustatymai",
    "Rename" : "Pervadinti",
    "Delete" : "Ištrinti",
    "Rename Feed" : "Pervadinti kanalą",
    "Open Feed URL" : "Atverti kanalo URL",
    "Unpin from top" : "Atsegti nuo viršaus",
    "Pin to top" : "Prisegti viršuje",
    "Newest first" : "Naujausi pirma",
    "Oldest first" : "Seniausi pirma",
    "Default order" : "Numatytoji tvarka",
    "Downloading article text" : "Atsisiunčiamas straipsnio tekstas",
    "Downloading of the article text has failed: {errorMessage}" : "Nepavyko atsisiųsti straipsnio teksto: {errorMessage}",
    "Show external media" : "Rodyti išorinę mediją",
    "from" : "nuo",
    "External media loaded from" : "Išorinė medija įkelta iš",
    "Previous Item" : "Ankstesnis elementas",
    "Next Item" : "Kitas elementas",
    "Undo article text replace" : "Atšaukti straipsnio teksto pakeitimą",
    "Download web version of this article" : "Atsisiųskite šio straipsnio žiniatinklio versiją",
    "Share within Instance" : "Dalintis šiame elemente",
    "Toggle star article" : "Perjungti straipsnio žymėjimą žvaigždute",
    "Mark unread" : "Žymėti kaip neskaitytą",
    "Close details" : "Užverti išsamesnę informaciją",
    "shared by" : "bendrina",
    "by" : " ",
    "Play audio" : "Atkurti garso įrašą",
    "Download audio" : "Atsisiųsti garso įrašą",
    "Download video" : "Atsisiųsti vaizdo įrašą",
    "Refresh list" : "Atnaujinti sąrašą",
    "Open website" : "Atverti svetainę",
    "Keep article unread" : "Palikti straipsnį neskaitytą",
    "Keep article unread (auto-filtered)" : "Palikti straipsnį neskaitytą (automatiškai filtruojama)",
    "Toggle keep current article unread" : "Perjungti: palikti dabartinį straipsnį kaip neskaitytą",
    "Remove keep article unread" : "Nebepalikti straipsnio neskaityto",
    "Default" : "Numatytasis",
    "Compact" : "Kompaktiškas",
    "Screenreader" : "Ekrano skaitytuvas",
    "Vertical" : "Vertikalus",
    "Horizontal" : "Horizontalus",
    "Off" : "Išjungta",
    "Always" : "Visada",
    "Ask" : "Klausti",
    "Never" : "Niekada",
    "Please select a valid OPML file" : "Pasirinkite tinkamą OPML failą",
    "File successfully uploaded" : "Failas įkeltas sėkmingai",
    "Error uploading the opml file" : "Klaida įkeliant OPML failą",
    "Error connecting to the server" : "Kyla problemų prisijungiant prie serverio",
    "Error retrieving the opml file" : "Klaida gaunant OPML failą",
    "Please select a valid json file" : "Prašome pasirinkti tinkamą JSON failą",
    "Error uploading the json file" : "Klaida įkeliant JSON failą",
    "Error retrieving the json file" : "Klaida gaunant JSON failą",
    "General" : "Bendra",
    "Disable mark read through scrolling" : "Išjungti žymėjimą kaip perskaitytą slenkant",
    "Reverse ordering (oldest on top)" : "Atvirkštinis rikiavimas (seniausi viršuje)",
    "Disable automatic refresh" : "Išjungti automatinį įkėlimą iš naujo",
    "Media" : "Medija",
    "Show embedded thumbnails" : "Rodyti įterptas miniatiūras",
    "Show enclosure images" : "Rodyti prisegtus paveikslėlius",
    "Show images in the article text" : "Rodyti paveikslėlius straipsnio tekste",
    "Show iframes in the article text" : "Rodyti įterptąjį turinį straipsnyje",
    "Appearance" : "Išvaizda",
    "Display mode" : "Ekrano režimas",
    "Split mode" : "Padalijimo režimas",
    "Import" : "Importuoti",
    "Export" : "Eksportuoti",
    "Abonnements (OPML)" : "Prenumeratos (OPML)",
    "Importing feeds" : "Importuojami sklaidos kanalai",
    "Please wait" : "Prašome palaukti",
    "Articles (JSON)" : "Straipsniai (JSON)",
    "Keyboard shortcuts" : "Klavišų kombinacijos",
    "Refresh" : "Įkelti iš naujo",
    "Screenreader mode only" : "Tik ekrano skaitytuvo režimas",
    "Jump to previous article" : "Peršokti į ankstesnį straipsnį",
    "Jump to next article" : "Peršokti į kitą straipsnį",
    "Item navigation and control" : "Elementų naršymas ir valdymas",
    "Open article in new tab" : "Atverti straipsnį naujoje kortelėje",
    "Show article details in compact view" : "Rodyti straipsnio informaciją kompaktiškame rodinyje",
    "Close article details in compact view" : "Uždaryti straipsnio informaciją kompaktiškame rodinyje",
    "Download web version of the selected article" : "Atsisiųsti pasirinkto straipsnio žiniatinklio versiją",
    "Feed/Folder navigation and control" : "Sklaidos kanalų / aplankų naršymas ir valdymas",
    "Jump to previous feed" : "Pereiti į ankstesnį sklaidos kanalą",
    "Jump to next feed" : "Pereiti prie kito sklaidos kanalo",
    "Jump to previous folder" : "Pereiti į ankstesnį aplanką",
    "Jump to next folder" : "Pereiti į kitą aplanką",
    "Mark current articles feed/folder as read" : "Pažymėti dabartinį straipsnių srautą / aplanką kaip perskaitytą",
    "Resources" : "Ištekliai",
    "Unable to update keyword filters. Please try again." : "Nepavyko atnaujinti raktinių žodžių filtrų. Bandykite dar kartą.",
    "Are you sure you want to delete {count} selected feeds?" : "Ar tikrai norite ištrinti {count} pasirinktus kanalus?",
    "Some selected feeds could not be deleted. Please try again later or check your connection." : "Kai kurių pasirinktų sklaidos kanalų ištrinti nepavyko. Bandykite dar kartą vėliau arba patikrinkite ryšį.",
    "Last update" : "Paskutinis atnaujinimas",
    "Time when the feed was last downloaded or modified" : "Laikas, kada paskutinį kartą buvo atsisiųstas arba pakeistas sklaidos kanalas",
    "Next update" : "Kitas atnaujinimas",
    "Time when the next feed update will be done" : "Laikas, kada bus atliktas kitas sklaidos kanalo atnaujinimas",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Tik jei įjungta administratoriaus nustatymuose, kitu atveju naudojamas įprastas atnaujinimo intervalas.",
    "Articles per update" : "Straipsniai per vieną atnaujinimą",
    "Maximum number of articles reached in a feed update" : "Pasiektas maksimalus straipsnių skaičius sklaidos kanalo atnaujinime",
    "Error Count" : "Klaidų skaičius",
    "Number of errors that have occurred since the last successful feed update" : "Klaidų, įvykusių nuo paskutinio sėkmingo sklaidos kanalo atnaujinimo, skaičius",
    "Feed fetch options" : "Sklaidos kanalo parinktys",
    "Feed update is enabled" : "Sklaidos kanalo naujinimas įjungtas",
    "Feed update is disabled" : "Sklaidos kanalo naujinimas išjungtas",
    "Keep read status on update" : "Išsaugoti skaitymo būseną atnaujinant",
    "Mark as unread on update" : "Pažymėti kaip neskaitytą atnaujinant",
    "Use article text provided by the feed" : "Naudoti straipsnio tekstą, pateiktą sklaidos kanale",
    "Scrape web version of the article text" : "Nukopijuokite straipsnio teksto versiją iš interneto",
    "Please note that web scraping may be blocked by some providers and is generally discouraged." : "Atkreipkite dėmesį, kad kai kurie paslaugų teikėjai gali blokuoti žiniatinklio nuskaitymą ir paprastai to nerekomenduojama daryti.",
    "Loading feeds" : "Įkeliami sklaidos kanalai",
    "Keyword filters" : "Raktinių žodžių filtrai",
    "Hide articles that match comma-separated keywords (case-insensitive) in the title, body, or URL" : "Slėpti straipsnius, kurie atitinka kableliais atskirtus raktinius žodžius (didžiųjų ir mažųjų raidžių neskiria) pavadinime, tekste arba URL",
    "Select all feeds" : "Pasirinkite visus kanalus",
    "Selected feeds" : "Pasirinkti kanalai",
    "Move selected" : "Perkelti pasirinktą",
    "Delete selected" : "Ištrinti pasirinktus",
    "Options" : "Parinktys",
    "Title" : "Pavadinimas",
    "Folder" : "Aplankas",
    "Select feed {feed}" : "Pasirinkite sklaidos kanalą {feed}",
    "Enable feed update" : "Įjungti sklaidos kanalo atnaujinimą",
    "Disable feed update" : "Išjungti sklaidos kanalo naujinimą",
    "Disable marking items as unread on update" : "Išjungti elementų žymėjimą kaip neskaitytų atnaujinant",
    "Enable marking items as unread on update" : "Įjungti elementų žymėjimą kaip neskaitytų atnaujinant",
    "Enable web scraping" : "Įgalinti žiniatinklio nuskaitymą",
    "Disable web scraping" : "Išjungti žiniatinklio nuskaitymą",
    "Not available" : "Nėra",
    "Keyword Filters for {feed}" : "Raktinių žodžių filtrai, skirti {feed}",
    "Matching is case-insensitive. Title and body keywords match whole words, while URL keywords match URL fragments." : "Atitikmenų paieška neskiria didžiųjų ir mažųjų raidžių. Pavadinimo ir teksto raktažodžiai atitinka ištisus žodžius, o URL raktažodžiai – URL fragmentus.",
    "Title keywords" : "Pavadinimo raktiniai žodžiai",
    "e.g. android, ios" : "pvz., „Android“, „iOS“",
    "Body keywords" : "Pagrindiniai raktažodžiai",
    "e.g. advertisement" : "pvz., reklama",
    "URL keywords" : "URL raktiniai žodžiai",
    "e.g. /sport/" : "pvz., /sportas/",
    "Save" : "Išsaugoti",
    "Clear" : "Išvalyti",
    "All Articles" : "Visi straipsniai",
    "No feeds found to add" : "Nerasta jokių sklaidos kanalų, kuriuos būtų galima pridėti",
    "Subscribe to" : "Prenumeruoti",
    "Unread Articles" : "Neskaityti straipsniai",
    "Empty Response" : "Tuščias atsakymas"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
